@@ -270,6 +270,13 @@ gssdp_client_initable_init (GInitable                   *initable,
                                          NULL));
 
         if (priv->search_socket != NULL) {
+                if (priv->msearch_port == 0) {
+                        g_object_get (priv->search_socket,
+                                      "port",
+                                      &priv->msearch_port,
+                                      NULL);
+                }
+
                 gssdp_socket_source_set_callback
                                         (priv->search_socket,
                                          (GSourceFunc) search_socket_source_cb,
@@ -1390,7 +1397,8 @@ gssdp_client_can_reach (GSSDPClient *client, GInetSocketAddress *address)
         GSSDPClientPrivate *priv = gssdp_client_get_instance_private (client);
 
         GInetAddress *addr = g_inet_socket_address_get_address (address);
-        if (g_inet_address_get_is_link_local (addr)) {
+        if (g_inet_address_get_is_link_local (addr) &&
+            g_inet_address_get_family (addr) == G_SOCKET_FAMILY_IPV6) {
                 return g_inet_socket_address_get_scope_id (address) ==
                        priv->device.index;
         }
@@ -1726,19 +1734,29 @@ socket_source_cb (GSSDPSocketSource *socket_source, GSSDPClient *client)
                                 msg = GSSDP_PKTINFO6_MESSAGE (messages[i]);
                                 msg_ifindex = gssdp_pktinfo6_message_get_ifindex (msg);
                                 local_addr = gssdp_pktinfo6_message_get_local_addr (msg);
-                        } else
+                        } else {
                                 continue;
+                        }
 
                         /* message needs to be on correct interface or on
                          * loopback (as kernel can be smart and route things
                          * there even if sent to another network) */
-                        if (!((msg_ifindex == priv->device.index ||
-                               msg_ifindex == LOOPBACK_IFINDEX) &&
-                              (g_inet_address_equal (local_addr,
-                                                     priv->device.host_addr) ||
-                               g_inet_address_equal (local_addr, group_addr)))) {
-                                goto out;
-                        } else {
+                        if (g_inet_address_equal (local_addr, group_addr)) {
+                                // This is a multicast packet. If the index is not our index, ignore
+                                if (msg_ifindex != priv->device.index) {
+                                        goto out;
+                                }
+                                break;
+                        }
+
+                        if (g_inet_address_equal (local_addr,
+                                                  priv->device.host_addr)) {
+                                // This is a "normal" packet. We can receive those
+
+                                if (msg_ifindex != priv->device.index &&
+                                    msg_ifindex != LOOPBACK_IFINDEX) {
+                                        goto out;
+                                }
                                 break;
                         }
                 }
@@ -2045,6 +2063,7 @@ init_network_info (GSSDPClient *client, GError **error)
         g_debug ("Created SSDP client %p", client);
         g_debug ("  iface_name : %s", priv->device.iface_name);
         g_debug ("  host_ip    : %s", gssdp_client_get_host_ip (client));
+        g_debug ("  port       : %u", gssdp_client_get_port (client));
         g_debug ("  server_id  : %s", priv->server_id);
         g_debug ("  network    : %s", priv->device.network);
         g_debug ("  index      : %d", priv->device.index);
